"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(
    hub,
    ctx,
    allocation_ids: List = None,
    attribute: str = None,
    next_token: str = None,
    max_results: int = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the attributes of the specified Elastic IP addresses. For requirements, see Using reverse DNS for email applications.

    Args:
        allocation_ids(List, optional): [EC2-VPC] The allocation IDs. Defaults to None.
        attribute(str, optional): The attribute of the IP address. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.address.attribute.describe(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.address.attribute.describe
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_addresses_attribute",
        op_kwargs={
            "AllocationIds": allocation_ids,
            "Attribute": attribute,
            "NextToken": next_token,
            "MaxResults": max_results,
            "DryRun": dry_run,
        },
    )


async def modify(
    hub, ctx, allocation_id: str, domain_name: str = None, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies an attribute of the specified Elastic IP address. For requirements, see Using reverse DNS for email applications.

    Args:
        allocation_id(str): [EC2-VPC] The allocation ID.
        domain_name(str, optional): The domain name to modify for the IP address. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.address.attribute.modify(ctx, allocation_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.address.attribute.modify allocation_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_address_attribute",
        op_kwargs={
            "AllocationId": allocation_id,
            "DomainName": domain_name,
            "DryRun": dry_run,
        },
    )


async def reset(
    hub, ctx, allocation_id: str, attribute: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Resets the attribute of the specified IP address. For requirements, see Using reverse DNS for email applications.

    Args:
        allocation_id(str): [EC2-VPC] The allocation ID.
        attribute(str): The attribute of the IP address.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.address.attribute.reset(
                ctx, allocation_id=value, attribute=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.address.attribute.reset allocation_id=value, attribute=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="reset_address_attribute",
        op_kwargs={
            "AllocationId": allocation_id,
            "Attribute": attribute,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"import_": "import"}


async def import_(
    hub,
    ctx,
    key_id: str,
    import_token: bytes,
    encrypted_key_material: bytes,
    valid_to: str = None,
    expiration_model: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Imports key material into an existing symmetric AWS KMS customer master key (CMK) that was created without key material. After you successfully import key material into a CMK, you can reimport the same key material into that CMK, but you cannot import different key material.  You cannot perform this operation on an asymmetric CMK or on any CMK in a different AWS account. For more information about creating CMKs with no key material and then importing key material, see Importing Key Material in the AWS Key Management Service Developer Guide. Before using this operation, call GetParametersForImport. Its response includes a public key and an import token. Use the public key to encrypt the key material. Then, submit the import token from the same GetParametersForImport response. When calling this operation, you must specify the following values:   The key ID or key ARN of a CMK with no key material. Its Origin must be EXTERNAL. To create a CMK with no key material, call CreateKey and set the value of its Origin parameter to EXTERNAL. To get the Origin of a CMK, call DescribeKey.)   The encrypted key material. To get the public key to encrypt the key material, call GetParametersForImport.   The import token that GetParametersForImport returned. You must use a public key and token from the same GetParametersForImport response.   Whether the key material expires and if so, when. If you set an expiration date, AWS KMS deletes the key material from the CMK on the specified date, and the CMK becomes unusable. To use the CMK again, you must reimport the same key material. The only way to change an expiration date is by reimporting the same key material and specifying a new expiration date.    When this operation is successful, the key state of the CMK changes from PendingImport to Enabled, and you can use the CMK. If this operation fails, use the exception to help determine the problem. If the error is related to the key material, the import token, or wrapping key, use GetParametersForImport to get a new public key and import token for the CMK and repeat the import procedure. For help, see How To Import Key Material in the AWS Key Management Service Developer Guide. The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: No. You cannot perform this operation on a CMK in a different AWS account.  Required permissions: kms:ImportKeyMaterial (key policy)  Related operations:     DeleteImportedKeyMaterial     GetParametersForImport

    Args:
        key_id(str): The identifier of the symmetric CMK that receives the imported key material. The CMK's Origin must be EXTERNAL. This must be the same CMK specified in the KeyID parameter of the corresponding GetParametersForImport request. Specify the key ID or key ARN of the CMK. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey.
        import_token(bytes): The import token that you received in the response to a previous GetParametersForImport request. It must be from the same response that contained the public key that you used to encrypt the key material.
        encrypted_key_material(bytes): The encrypted key material to import. The key material must be encrypted with the public wrapping key that GetParametersForImport returned, using the wrapping algorithm that you specified in the same GetParametersForImport request.
        valid_to(str, optional): The time at which the imported key material expires. When the key material expires, AWS KMS deletes the key material and the CMK becomes unusable. You must omit this parameter when the ExpirationModel parameter is set to KEY_MATERIAL_DOES_NOT_EXPIRE. Otherwise it is required. Defaults to None.
        expiration_model(str, optional): Specifies whether the key material expires. The default is KEY_MATERIAL_EXPIRES, in which case you must include the ValidTo parameter. When this parameter is set to KEY_MATERIAL_DOES_NOT_EXPIRE, you must omit the ValidTo parameter. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.key.material.import(ctx, key_id=value, import_token=value, encrypted_key_material=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.key.material.import key_id=value, import_token=value, encrypted_key_material=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="import_key_material",
        op_kwargs={
            "KeyId": key_id,
            "ImportToken": import_token,
            "EncryptedKeyMaterial": encrypted_key_material,
            "ValidTo": valid_to,
            "ExpirationModel": expiration_model,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def disassociate(
    hub, ctx, application_configuration_id: str, configuration_ids: List
) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates one or more configuration items from an application.

    Args:
        application_configuration_id(str): Configuration ID of an application from which each item is disassociated.
        configuration_ids(List): Configuration ID of each item to be disassociated from an application.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.discovery.configuration.item.from_application.disassociate(
                ctx, application_configuration_id=value, configuration_ids=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.discovery.configuration.item.from_application.disassociate application_configuration_id=value, configuration_ids=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="discovery",
        operation="disassociate_configuration_items_from_application",
        op_kwargs={
            "applicationConfigurationId": application_configuration_id,
            "configurationIds": configuration_ids,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, from_time: str, to_time: str = None) -> Dict:
    r"""
    **Autogenerated function**

     For the time range passed in, returns the number of open reactive insight that were created, the number of open proactive insights that were created, and the Mean Time to Recover (MTTR) for all closed reactive insights.

    Args:
        from_time(str):  The start of the time range passed in. The start time granularity is at the day level. The floor of the start time is used. Returned information occurred after this day. .
        to_time(str, optional):  The end of the time range passed in. The start time granularity is at the day level. The floor of the start time is used. Returned information occurred before this day. If this is not specified, then the current day is used. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.devop_guru.account.overview.describe(ctx, from_time=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.devop_guru.account.overview.describe from_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="devops-guru",
        operation="describe_account_overview",
        op_kwargs={"FromTime": from_time, "ToTime": to_time},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    start_time: str,
    end_time: str,
    time_range_type: str = None,
    sampling: bool = None,
    sampling_strategy: Dict = None,
    filter_expression: str = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves IDs and annotations for traces available for a specified time frame using an optional filter. To get the full traces, pass the trace IDs to BatchGetTraces. A filter expression can target traced requests that hit specific service nodes or edges, have errors, or come from a known user. For example, the following filter expression targets traces that pass through api.example.com:  service("api.example.com")  This filter expression finds traces that have an annotation named account with the value 12345:  annotation.account = "12345"  For a full list of indexed fields and keywords that you can use in filter expressions, see Using Filter Expressions in the AWS X-Ray Developer Guide.

    Args:
        start_time(str): The start of the time frame for which to retrieve traces.
        end_time(str): The end of the time frame for which to retrieve traces.
        time_range_type(str, optional): A parameter to indicate whether to query trace summaries by TraceId or Event time. Defaults to None.
        sampling(bool, optional): Set to true to get summaries for only a subset of available traces. Defaults to None.
        sampling_strategy(Dict, optional): A parameter to indicate whether to enable sampling on trace summaries. Input parameters are Name and Value. Defaults to None.
        filter_expression(str, optional): Specify a filter expression to retrieve trace summaries for services or requests that meet certain requirements. Defaults to None.
        next_token(str, optional): Specify the pagination token returned by a previous request to retrieve the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.xray.trace.summary.get_all(
                ctx, start_time=value, end_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.xray.trace.summary.get_all start_time=value, end_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="xray",
        operation="get_trace_summaries",
        op_kwargs={
            "StartTime": start_time,
            "EndTime": end_time,
            "TimeRangeType": time_range_type,
            "Sampling": sampling,
            "SamplingStrategy": sampling_strategy,
            "FilterExpression": filter_expression,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    vpc_id: str,
    cidr_block: str,
    tag_specifications: List = None,
    availability_zone: str = None,
    availability_zone_id: str = None,
    ipv6_cidr_block: str = None,
    outpost_arn: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a subnet in a specified VPC. You must specify an IPv4 CIDR block for the subnet. After you create a subnet, you can't change its CIDR block. The allowed block size is between a /16 netmask (65,536 IP addresses) and /28 netmask (16 IP addresses). The CIDR block must not overlap with the CIDR block of an existing subnet in the VPC. If you've associated an IPv6 CIDR block with your VPC, you can create a subnet with an IPv6 CIDR block that uses a /64 prefix length.   Amazon Web Services reserves both the first four and the last IPv4 address in each subnet's CIDR block. They're not available for use.  If you add more than one subnet to a VPC, they're set up in a star topology with a logical router in the middle. When you stop an instance in a subnet, it retains its private IPv4 address. It's therefore possible to have a subnet with no running instances (they're all stopped), but no remaining IP addresses available. For more information about subnets, see Your VPC and subnets in the Amazon Virtual Private Cloud User Guide.

    Args:
        tag_specifications(List, optional): The tags to assign to the subnet. Defaults to None.
        availability_zone(str, optional): The Availability Zone or Local Zone for the subnet. Default: Amazon Web Services selects one for you. If you create more than one subnet in your VPC, we do not necessarily select a different zone for each subnet. To create a subnet in a Local Zone, set this value to the Local Zone ID, for example us-west-2-lax-1a. For information about the Regions that support Local Zones, see Available Regions in the Amazon Elastic Compute Cloud User Guide. To create a subnet in an Outpost, set this value to the Availability Zone for the Outpost and specify the Outpost ARN. Defaults to None.
        availability_zone_id(str, optional): The AZ ID or the Local Zone ID of the subnet. Defaults to None.
        ipv6_cidr_block(str, optional): The IPv6 network range for the subnet, in CIDR notation. The subnet size must use a /64 prefix length. Defaults to None.
        outpost_arn(str, optional): The Amazon Resource Name (ARN) of the Outpost. If you specify an Outpost ARN, you must also specify the Availability Zone of the Outpost subnet. Defaults to None.
        vpc_id(str): The ID of the VPC.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        cidr_block(str): The IPv4 network range for the subnet, in CIDR notation. For example, 10.0.0.0/24. We modify the specified CIDR block to its canonical form; for example, if you specify 100.68.0.18/18, we modify it to 100.68.0.0/18.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.subnet.init.create(ctx, vpc_id=value, cidr_block=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.subnet.init.create vpc_id=value, cidr_block=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_subnet",
        op_kwargs={
            "TagSpecifications": tag_specifications,
            "AvailabilityZone": availability_zone,
            "AvailabilityZoneId": availability_zone_id,
            "Ipv6CidrBlock": ipv6_cidr_block,
            "OutpostArn": outpost_arn,
            "VpcId": vpc_id,
            "DryRun": dry_run,
            "CidrBlock": cidr_block,
        },
    )


async def delete(hub, ctx, subnet_id: str, dry_run: bool = None) -> None:
    r"""
    **Autogenerated function**

    Deletes the specified subnet. You must terminate all running instances in the subnet before you can delete the subnet.

    Args:
        subnet_id(str): The ID of the subnet.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.subnet.init.delete(ctx, subnet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.subnet.init.delete subnet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_subnet",
        op_kwargs={"SubnetId": subnet_id, "DryRun": dry_run},
    )


async def describe_all(
    hub,
    ctx,
    filters: List = None,
    subnet_ids: List = None,
    dry_run: bool = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more of your subnets. For more information, see Your VPC and subnets in the Amazon Virtual Private Cloud User Guide.

    Args:
        filters(List, optional): One or more filters.    availability-zone - The Availability Zone for the subnet. You can also use availabilityZone as the filter name.    availability-zone-id - The ID of the Availability Zone for the subnet. You can also use availabilityZoneId as the filter name.    available-ip-address-count - The number of IPv4 addresses in the subnet that are available.    cidr-block - The IPv4 CIDR block of the subnet. The CIDR block you specify must exactly match the subnet's CIDR block for information to be returned for the subnet. You can also use cidr or cidrBlock as the filter names.    default-for-az - Indicates whether this is the default subnet for the Availability Zone. You can also use defaultForAz as the filter name.    ipv6-cidr-block-association.ipv6-cidr-block - An IPv6 CIDR block associated with the subnet.    ipv6-cidr-block-association.association-id - An association ID for an IPv6 CIDR block associated with the subnet.    ipv6-cidr-block-association.state - The state of an IPv6 CIDR block associated with the subnet.    outpost-arn - The Amazon Resource Name (ARN) of the Outpost.    owner-id - The ID of the Amazon Web Services account that owns the subnet.    state - The state of the subnet (pending | available).    subnet-arn - The Amazon Resource Name (ARN) of the subnet.    subnet-id - The ID of the subnet.    tag:<key> - The key/value combination of a tag assigned to the resource. Use the tag key in the filter name and the tag value as the filter value. For example, to find all resources that have a tag with the key Owner and the value TeamA, specify tag:Owner for the filter name and TeamA for the filter value.    tag-key - The key of a tag assigned to the resource. Use this filter to find all resources assigned a tag with a specific key, regardless of the tag value.    vpc-id - The ID of the VPC for the subnet.  . Defaults to None.
        subnet_ids(List, optional): One or more subnet IDs. Default: Describes all your subnets. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.subnet.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.subnet.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_subnets",
        op_kwargs={
            "Filters": filters,
            "SubnetIds": subnet_ids,
            "DryRun": dry_run,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, notebook_execution_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Provides details of a notebook execution.

    Args:
        notebook_execution_id(str): The unique identifier of the notebook execution.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.notebook_execution.describe(
                ctx, notebook_execution_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.notebook_execution.describe notebook_execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="describe_notebook_execution",
        op_kwargs={"NotebookExecutionId": notebook_execution_id},
    )


async def list_all(
    hub,
    ctx,
    editor_id: str = None,
    status: str = None,
    from_: str = None,
    to: str = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Provides summaries of all notebook executions. You can filter the list based on multiple criteria such as status, time range, and editor id. Returns a maximum of 50 notebook executions and a marker to track the paging of a longer notebook execution list across multiple ListNotebookExecution calls.

    Args:
        editor_id(str, optional): The unique ID of the editor associated with the notebook execution. Defaults to None.
        status(str, optional): The status filter for listing notebook executions.    START_PENDING indicates that the cluster has received the execution request but execution has not begun.    STARTING indicates that the execution is starting on the cluster.    RUNNING indicates that the execution is being processed by the cluster.    FINISHING indicates that execution processing is in the final stages.    FINISHED indicates that the execution has completed without error.    FAILING indicates that the execution is failing and will not finish successfully.    FAILED indicates that the execution failed.    STOP_PENDING indicates that the cluster has received a StopNotebookExecution request and the stop is pending.    STOPPING indicates that the cluster is in the process of stopping the execution as a result of a StopNotebookExecution request.    STOPPED indicates that the execution stopped because of a StopNotebookExecution request.  . Defaults to None.
        from_(str, optional): The beginning of time range filter for listing notebook executions. The default is the timestamp of 30 days ago. Defaults to None.
        to(str, optional): The end of time range filter for listing notebook executions. The default is the current timestamp. Defaults to None.
        marker(str, optional): The pagination token, returned by a previous ListNotebookExecutions call, that indicates the start of the list for this ListNotebookExecutions call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.notebook_execution.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.notebook_execution.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="list_notebook_executions",
        op_kwargs={
            "EditorId": editor_id,
            "Status": status,
            "From": from_,
            "To": to,
            "Marker": marker,
        },
    )


async def start(
    hub,
    ctx,
    editor_id: str,
    relative_path: str,
    execution_engine: Dict,
    service_role: str,
    notebook_execution_name: str = None,
    notebook_params: str = None,
    notebook_instance_security_group_id: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a notebook execution.

    Args:
        editor_id(str): The unique identifier of the EMR Notebook to use for notebook execution.
        relative_path(str): The path and file name of the notebook file for this execution, relative to the path specified for the EMR Notebook. For example, if you specify a path of s3://MyBucket/MyNotebooks when you create an EMR Notebook for a notebook with an ID of e-ABCDEFGHIJK1234567890ABCD (the EditorID of this request), and you specify a RelativePath of my_notebook_executions/notebook_execution.ipynb, the location of the file for the notebook execution is s3://MyBucket/MyNotebooks/e-ABCDEFGHIJK1234567890ABCD/my_notebook_executions/notebook_execution.ipynb.
        notebook_execution_name(str, optional): An optional name for the notebook execution. Defaults to None.
        notebook_params(str, optional): Input parameters in JSON format passed to the EMR Notebook at runtime for execution. Defaults to None.
        execution_engine(Dict): Specifies the execution engine (cluster) that runs the notebook execution.
        service_role(str): The name or ARN of the IAM role that is used as the service role for Amazon EMR (the EMR role) for the notebook execution.
        notebook_instance_security_group_id(str, optional): The unique identifier of the Amazon EC2 security group to associate with the EMR Notebook for this notebook execution. Defaults to None.
        tags(List, optional): A list of tags associated with a notebook execution. Tags are user-defined key-value pairs that consist of a required key string with a maximum of 128 characters and an optional value string with a maximum of 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.notebook_execution.start(
                ctx,
                editor_id=value,
                relative_path=value,
                execution_engine=value,
                service_role=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.notebook_execution.start editor_id=value, relative_path=value, execution_engine=value, service_role=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="start_notebook_execution",
        op_kwargs={
            "EditorId": editor_id,
            "RelativePath": relative_path,
            "NotebookExecutionName": notebook_execution_name,
            "NotebookParams": notebook_params,
            "ExecutionEngine": execution_engine,
            "ServiceRole": service_role,
            "NotebookInstanceSecurityGroupId": notebook_instance_security_group_id,
            "Tags": tags,
        },
    )


async def stop(hub, ctx, notebook_execution_id: str) -> None:
    r"""
    **Autogenerated function**

    Stops a notebook execution.

    Args:
        notebook_execution_id(str): The unique identifier of the notebook execution.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr.notebook_execution.stop(ctx, notebook_execution_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr.notebook_execution.stop notebook_execution_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr",
        operation="stop_notebook_execution",
        op_kwargs={"NotebookExecutionId": notebook_execution_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def validate(hub, ctx, behaviors: List) -> Dict:
    r"""
    **Autogenerated function**

    Validates a Device Defender security profile behaviors specification.

    Args:
        behaviors(List): Specifies the behaviors that, when violated by a device (thing), cause an alert.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.security_profile.behavior.validate(ctx, behaviors=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.security_profile.behavior.validate behaviors=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="validate_security_profile_behaviors",
        op_kwargs={"behaviors": behaviors},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def delete(hub, ctx, domain_name: str, tags_to_delete: List) -> Dict:
    r"""
    **Autogenerated function**

    This operation deletes the specified tags for a domain. All tag operations are eventually consistent; subsequent operations might not immediately represent all issued operations.

    Args:
        domain_name(str): The domain for which you want to delete one or more tags.
        tags_to_delete(List): A list of tag keys to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.tags_for_domain.delete(
                ctx, domain_name=value, tags_to_delete=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.tags_for_domain.delete domain_name=value, tags_to_delete=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="delete_tags_for_domain",
        op_kwargs={"DomainName": domain_name, "TagsToDelete": tags_to_delete},
    )


async def list_(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    This operation returns all of the tags that are associated with the specified domain. All tag operations are eventually consistent; subsequent operations might not immediately represent all issued operations.

    Args:
        domain_name(str): The domain for which you want to get a list of tags.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.tags_for_domain.list(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.tags_for_domain.list domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="list_tags_for_domain",
        op_kwargs={"DomainName": domain_name},
    )


async def update(hub, ctx, domain_name: str, tags_to_update: List = None) -> Dict:
    r"""
    **Autogenerated function**

    This operation adds or updates tags for a specified domain. All tag operations are eventually consistent; subsequent operations might not immediately represent all issued operations.

    Args:
        domain_name(str): The domain for which you want to add or update tags.
        tags_to_update(List, optional): A list of the tag keys and values that you want to add or update. If you specify a key that already exists, the corresponding value will be replaced. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.route53domain.tags_for_domain.update(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.route53domain.tags_for_domain.update domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="route53domains",
        operation="update_tags_for_domain",
        op_kwargs={"DomainName": domain_name, "TagsToUpdate": tags_to_update},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__virtualname__ = "type"


async def create(hub, ctx, api_id: str, definition: str, format_: str) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Type object.

    Args:
        api_id(str): The API ID.
        definition(str): The type definition, in GraphQL Schema Definition Language (SDL) format. For more information, see the GraphQL SDL documentation.
        format_(str): The type format: SDL or JSON.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.type_.create(
                ctx, api_id=value, definition=value, format_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.type.create api_id=value, definition=value, format_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="create_type",
        op_kwargs={"apiId": api_id, "definition": definition, "format": format_},
    )


async def delete(hub, ctx, api_id: str, type_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Type object.

    Args:
        api_id(str): The API ID.
        type_name(str): The type name.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.type_.delete(ctx, api_id=value, type_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.type.delete api_id=value, type_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="delete_type",
        op_kwargs={"apiId": api_id, "typeName": type_name},
    )


async def get(hub, ctx, api_id: str, type_name: str, format_: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves a Type object.

    Args:
        api_id(str): The API ID.
        type_name(str): The type name.
        format_(str): The type format: SDL or JSON.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.type_.get(
                ctx, api_id=value, type_name=value, format_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.type.get api_id=value, type_name=value, format_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="get_type",
        op_kwargs={"apiId": api_id, "typeName": type_name, "format": format_},
    )


async def list_all(
    hub, ctx, api_id: str, format_: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the types for a given API.

    Args:
        api_id(str): The API ID.
        format_(str): The type format: SDL or JSON.
        next_token(str, optional): An identifier that was returned from the previous call to this operation, which can be used to return the next set of items in the list. . Defaults to None.
        max_results(int, optional): The maximum number of results you want the request to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.type_.list_all(ctx, api_id=value, format_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.type.list_all api_id=value, format_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="list_types",
        op_kwargs={
            "apiId": api_id,
            "format": format_,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub, ctx, api_id: str, type_name: str, format_: str, definition: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a Type object.

    Args:
        api_id(str): The API ID.
        type_name(str): The new type name.
        definition(str, optional): The new definition. Defaults to None.
        format_(str): The new type format: SDL or JSON.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.appsync.type_.update(
                ctx, api_id=value, type_name=value, format_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.appsync.type.update api_id=value, type_name=value, format_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="appsync",
        operation="update_type",
        op_kwargs={
            "apiId": api_id,
            "typeName": type_name,
            "definition": definition,
            "format": format_,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, name: str, checksum: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new version of a slot type based on the $LATEST version of the specified slot type. If the $LATEST version of this resource has not changed since the last version that you created, Amazon Lex doesn't create a new version. It returns the last version that you created.   You can update only the $LATEST version of a slot type. You can't update the numbered versions that you create with the CreateSlotTypeVersion operation.  When you create a version of a slot type, Amazon Lex sets the version to 1. Subsequent versions increment by 1. For more information, see versioning-intro.  This operation requires permissions for the lex:CreateSlotTypeVersion action.

    Args:
        name(str): The name of the slot type that you want to create a new version for. The name is case sensitive. .
        checksum(str, optional): Checksum for the $LATEST version of the slot type that you want to publish. If you specify a checksum and the $LATEST version of the slot type has a different checksum, Amazon Lex returns a PreconditionFailedException exception and doesn't publish the new version. If you don't specify a checksum, Amazon Lex publishes the $LATEST version. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.slot_type_.version.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.slot_type_.version.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="create_slot_type_version",
        op_kwargs={"name": name, "checksum": checksum},
    )


async def delete(hub, ctx, name: str, version: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a specific version of a slot type. To delete all versions of a slot type, use the DeleteSlotType operation.  This operation requires permissions for the lex:DeleteSlotTypeVersion action.

    Args:
        name(str): The name of the slot type.
        version(str): The version of the slot type to delete. You cannot delete the $LATEST version of the slot type. To delete the $LATEST version, use the DeleteSlotType operation.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.slot_type_.version.delete(
                ctx, name=value, version=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.slot_type_.version.delete name=value, version=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="delete_slot_type_version",
        op_kwargs={"name": name, "version": version},
    )


async def get_all(
    hub, ctx, name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about all versions of a slot type. The GetSlotTypeVersions operation returns a SlotTypeMetadata object for each version of a slot type. For example, if a slot type has three numbered versions, the GetSlotTypeVersions operation returns four SlotTypeMetadata objects in the response, one for each numbered version and one for the $LATEST version.  The GetSlotTypeVersions operation always returns at least one version, the $LATEST version. This operation requires permissions for the lex:GetSlotTypeVersions action.

    Args:
        name(str): The name of the slot type for which versions should be returned.
        next_token(str, optional): A pagination token for fetching the next page of slot type versions. If the response to this call is truncated, Amazon Lex returns a pagination token in the response. To fetch the next page of versions, specify the pagination token in the next request. . Defaults to None.
        max_results(int, optional): The maximum number of slot type versions to return in the response. The default is 10. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lex_model.slot_type_.version.get_all(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lex_model.slot_type_.version.get_all name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lex-models",
        operation="get_slot_type_versions",
        op_kwargs={"name": name, "nextToken": next_token, "maxResults": max_results},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Gets the encryption key if a Key Management Service (KMS) customer master key (CMK) has been specified to be used to encrypt content in Amazon Fraud Detector.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.kms_encryption_key.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.kms_encryption_key.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="get_kms_encryption_key",
        op_kwargs={},
    )


async def put(hub, ctx, kms_encryption_key_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Specifies the Key Management Service (KMS) customer master key (CMK) to be used to encrypt content in Amazon Fraud Detector.

    Args:
        kms_encryption_key_arn(str): The KMS encryption key ARN.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.frauddetector.kms_encryption_key.put(
                ctx, kms_encryption_key_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.frauddetector.kms_encryption_key.put kms_encryption_key_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="frauddetector",
        operation="put_kms_encryption_key",
        op_kwargs={"kmsEncryptionKeyArn": kms_encryption_key_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, repository_name: str, catalog_data: Dict = None, tags: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a repository in a public registry. For more information, see Amazon ECR repositories in the Amazon Elastic Container Registry User Guide.

    Args:
        repository_name(str): The name to use for the repository. This appears publicly in the Amazon ECR Public Gallery. The repository name may be specified on its own (such as nginx-web-app) or it can be prepended with a namespace to group the repository into a category (such as project-a/nginx-web-app).
        catalog_data(Dict, optional): The details about the repository that are publicly visible in the Amazon ECR Public Gallery. Defaults to None.
        tags(List, optional): The metadata that you apply to the repository to help you categorize and organize them. Each tag consists of a key and an optional value, both of which you define. Tag keys can have a maximum character length of 128 characters, and tag values can have a maximum length of 256 characters. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.repository.init.create(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.repository.init.create repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="create_repository",
        op_kwargs={
            "repositoryName": repository_name,
            "catalogData": catalog_data,
            "tags": tags,
        },
    )


async def delete(
    hub, ctx, repository_name: str, registry_id: str = None, force: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a repository in a public registry. If the repository contains images, you must either delete all images in the repository or use the force option which deletes all images on your behalf before deleting the repository.

    Args:
        registry_id(str, optional): The AWS account ID associated with the public registry that contains the repository to delete. If you do not specify a registry, the default public registry is assumed. Defaults to None.
        repository_name(str): The name of the repository to delete.
        force(bool, optional):  If a repository contains images, forces the deletion. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.repository.init.delete(ctx, repository_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.repository.init.delete repository_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="delete_repository",
        op_kwargs={
            "registryId": registry_id,
            "repositoryName": repository_name,
            "force": force,
        },
    )


async def describe_all(
    hub,
    ctx,
    registry_id: str = None,
    repository_names: List = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes repositories in a public registry.

    Args:
        registry_id(str, optional): The AWS account ID associated with the registry that contains the repositories to be described. If you do not specify a registry, the default public registry is assumed. Defaults to None.
        repository_names(List, optional): A list of repositories to describe. If this parameter is omitted, then all repositories in a registry are described. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated DescribeRepositories request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value. This value is null when there are no more results to return. This option cannot be used when you specify repositories with repositoryNames.  This token should be treated as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        max_results(int, optional): The maximum number of repository results returned by DescribeRepositories in paginated output. When this parameter is used, DescribeRepositories only returns maxResults results in a single page along with a nextToken response element. The remaining results of the initial request can be seen by sending another DescribeRepositories request with the returned nextToken value. This value can be between 1 and 1000. If this parameter is not used, then DescribeRepositories returns up to 100 results and a nextToken value, if applicable. This option cannot be used when you specify repositories with repositoryNames. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ecr_public.repository.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ecr_public.repository.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ecr-public",
        operation="describe_repositories",
        op_kwargs={
            "registryId": registry_id,
            "repositoryNames": repository_names,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    password: str,
    vpc_settings: Dict,
    short_name: str = None,
    description: str = None,
    edition: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Microsoft AD directory in the AWS Cloud. For more information, see AWS Managed Microsoft AD in the AWS Directory Service Admin Guide. Before you call CreateMicrosoftAD, ensure that all of the required permissions have been explicitly granted through a policy. For details about what permissions are required to run the CreateMicrosoftAD operation, see AWS Directory Service API Permissions: Actions, Resources, and Conditions Reference.

    Args:
        name(str): The fully qualified domain name for the AWS Managed Microsoft AD directory, such as corp.example.com. This name will resolve inside your VPC only. It does not need to be publicly resolvable.
        short_name(str, optional): The NetBIOS name for your domain, such as CORP. If you don't specify a NetBIOS name, it will default to the first part of your directory DNS. For example, CORP for the directory DNS corp.example.com. . Defaults to None.
        password(str): The password for the default administrative user named Admin. If you need to change the password for the administrator account, you can use the ResetUserPassword API call.
        description(str, optional): A description for the directory. This label will appear on the AWS console Directory Details page after the directory is created. Defaults to None.
        vpc_settings(Dict): Contains VPC information for the CreateDirectory or CreateMicrosoftAD operation.
        edition(str, optional): AWS Managed Microsoft AD is available in two editions: Standard and Enterprise. Enterprise is the default. Defaults to None.
        tags(List, optional): The tags to be assigned to the AWS Managed Microsoft AD directory. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ds.microsoft_ad.create(
                ctx, name=value, password=value, vpc_settings=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ds.microsoft_ad.create name=value, password=value, vpc_settings=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ds",
        operation="create_microsoft_ad",
        op_kwargs={
            "Name": name,
            "ShortName": short_name,
            "Password": password,
            "Description": description,
            "VpcSettings": vpc_settings,
            "Edition": edition,
            "Tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    server_id: str,
    seed_replication_time: str,
    frequency: int = None,
    run_once: bool = None,
    license_type: str = None,
    role_name: str = None,
    description: str = None,
    number_of_recent_amis_to_keep: int = None,
    encrypted: bool = None,
    kms_key_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a replication job. The replication job schedules periodic replication runs to replicate your server to AWS. Each replication run creates an Amazon Machine Image (AMI).

    Args:
        server_id(str): The ID of the server.
        seed_replication_time(str): The seed replication time.
        frequency(int, optional): The time between consecutive replication runs, in hours. Defaults to None.
        run_once(bool, optional): Indicates whether to run the replication job one time. Defaults to None.
        license_type(str, optional): The license type to be used for the AMI created by a successful replication run. Defaults to None.
        role_name(str, optional): The name of the IAM role to be used by the AWS SMS. Defaults to None.
        description(str, optional): The description of the replication job. Defaults to None.
        number_of_recent_amis_to_keep(int, optional): The maximum number of SMS-created AMIs to retain. The oldest is deleted after the maximum number is reached and a new AMI is created. Defaults to None.
        encrypted(bool, optional): Indicates whether the replication job produces encrypted AMIs. Defaults to None.
        kms_key_id(str, optional): The ID of the KMS key for replication jobs that produce encrypted AMIs. This value can be any of the following:   KMS key ID   KMS key alias   ARN referring to the KMS key ID   ARN referring to the KMS key alias    If encrypted is true but a KMS key ID is not specified, the customer's default KMS key for Amazon EBS is used. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.replication.job.create(
                ctx, server_id=value, seed_replication_time=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.replication.job.create server_id=value, seed_replication_time=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="create_replication_job",
        op_kwargs={
            "serverId": server_id,
            "seedReplicationTime": seed_replication_time,
            "frequency": frequency,
            "runOnce": run_once,
            "licenseType": license_type,
            "roleName": role_name,
            "description": description,
            "numberOfRecentAmisToKeep": number_of_recent_amis_to_keep,
            "encrypted": encrypted,
            "kmsKeyId": kms_key_id,
        },
    )


async def delete(hub, ctx, replication_job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified replication job. After you delete a replication job, there are no further replication runs. AWS deletes the contents of the Amazon S3 bucket used to store AWS SMS artifacts. The AMIs created by the replication runs are not deleted.

    Args:
        replication_job_id(str): The ID of the replication job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.replication.job.delete(ctx, replication_job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.replication.job.delete replication_job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="delete_replication_job",
        op_kwargs={"replicationJobId": replication_job_id},
    )


async def get_all(
    hub,
    ctx,
    replication_job_id: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the specified replication job or all of your replication jobs.

    Args:
        replication_job_id(str, optional): The ID of the replication job. Defaults to None.
        next_token(str, optional): The token for the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in a single call. The default value is 50. To retrieve the remaining results, make another call with the returned NextToken value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.replication.job.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.replication.job.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="get_replication_jobs",
        op_kwargs={
            "replicationJobId": replication_job_id,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    replication_job_id: str,
    frequency: int = None,
    next_replication_run_start_time: str = None,
    license_type: str = None,
    role_name: str = None,
    description: str = None,
    number_of_recent_amis_to_keep: int = None,
    encrypted: bool = None,
    kms_key_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified settings for the specified replication job.

    Args:
        replication_job_id(str): The ID of the replication job.
        frequency(int, optional): The time between consecutive replication runs, in hours. Defaults to None.
        next_replication_run_start_time(str, optional): The start time of the next replication run. Defaults to None.
        license_type(str, optional): The license type to be used for the AMI created by a successful replication run. Defaults to None.
        role_name(str, optional): The name of the IAM role to be used by AWS SMS. Defaults to None.
        description(str, optional): The description of the replication job. Defaults to None.
        number_of_recent_amis_to_keep(int, optional): The maximum number of SMS-created AMIs to retain. The oldest is deleted after the maximum number is reached and a new AMI is created. Defaults to None.
        encrypted(bool, optional): When true, the replication job produces encrypted AMIs. For more information, KmsKeyId. Defaults to None.
        kms_key_id(str, optional): The ID of the KMS key for replication jobs that produce encrypted AMIs. This value can be any of the following:   KMS key ID   KMS key alias   ARN referring to the KMS key ID   ARN referring to the KMS key alias   If encrypted is enabled but a KMS key ID is not specified, the customer's default KMS key for Amazon EBS is used. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sms.replication.job.update(ctx, replication_job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sms.replication.job.update replication_job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sms",
        operation="update_replication_job",
        op_kwargs={
            "replicationJobId": replication_job_id,
            "frequency": frequency,
            "nextReplicationRunStartTime": next_replication_run_start_time,
            "licenseType": license_type,
            "roleName": role_name,
            "description": description,
            "numberOfRecentAmisToKeep": number_of_recent_amis_to_keep,
            "encrypted": encrypted,
            "kmsKeyId": kms_key_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


__func_alias__ = {"import_": "import"}


async def create(
    hub,
    ctx,
    app_id: str,
    backend_environment_name: str,
    resource_config: Dict,
    resource_name: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new backend authentication resource.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        resource_config(Dict): The resource configuration for this request object.
        resource_name(str): The name of this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.auth.create(ctx, app_id=value, backend_environment_name=value, resource_config=value, resource_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.auth.create app_id=value, backend_environment_name=value, resource_config=value, resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="create_backend_auth",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "ResourceConfig": resource_config,
            "ResourceName": resource_name,
        },
    )


async def delete(
    hub, ctx, app_id: str, backend_environment_name: str, resource_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes an existing backend authentication resource.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        resource_name(str): The name of this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.auth.delete(ctx, app_id=value, backend_environment_name=value, resource_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.auth.delete app_id=value, backend_environment_name=value, resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="delete_backend_auth",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "ResourceName": resource_name,
        },
    )


async def get(
    hub, ctx, app_id: str, backend_environment_name: str, resource_name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a backend auth details.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        resource_name(str): The name of this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.auth.get(ctx, app_id=value, backend_environment_name=value, resource_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.auth.get app_id=value, backend_environment_name=value, resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="get_backend_auth",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "ResourceName": resource_name,
        },
    )


async def import_(
    hub,
    ctx,
    app_id: str,
    backend_environment_name: str,
    native_client_id: str,
    user_pool_id: str,
    web_client_id: str,
    identity_pool_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Imports an existing backend authentication resource.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        identity_pool_id(str, optional): The ID of the Amazon Cognito identity pool. Defaults to None.
        native_client_id(str): The ID of the Amazon Cognito native client.
        user_pool_id(str): The ID of the Amazon Cognito user pool.
        web_client_id(str): The ID of the Amazon Cognito web client.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.auth.import(ctx, app_id=value, backend_environment_name=value, native_client_id=value, user_pool_id=value, web_client_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.auth.import app_id=value, backend_environment_name=value, native_client_id=value, user_pool_id=value, web_client_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="import_backend_auth",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "IdentityPoolId": identity_pool_id,
            "NativeClientId": native_client_id,
            "UserPoolId": user_pool_id,
            "WebClientId": web_client_id,
        },
    )


async def update(
    hub,
    ctx,
    app_id: str,
    backend_environment_name: str,
    resource_config: Dict,
    resource_name: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing backend authentication resource.

    Args:
        app_id(str): The app ID.
        backend_environment_name(str): The name of the backend environment.
        resource_config(Dict): The resource configuration for this request object.
        resource_name(str): The name of this resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.amplifybackend.backend.auth.update(ctx, app_id=value, backend_environment_name=value, resource_config=value, resource_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.amplifybackend.backend.auth.update app_id=value, backend_environment_name=value, resource_config=value, resource_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="amplifybackend",
        operation="update_backend_auth",
        op_kwargs={
            "AppId": app_id,
            "BackendEnvironmentName": backend_environment_name,
            "ResourceConfig": resource_config,
            "ResourceName": resource_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def detect(
    hub,
    ctx,
    stack_set_name: str,
    operation_preferences: Dict = None,
    operation_id: str = None,
    call_as: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Detect drift on a stack set. When CloudFormation performs drift detection on a stack set, it performs drift detection on the stack associated with each stack instance in the stack set. For more information, see How CloudFormation Performs Drift Detection on a Stack Set.  DetectStackSetDrift returns the OperationId of the stack set drift detection operation. Use this operation id with  DescribeStackSetOperation  to monitor the progress of the drift detection operation. The drift detection operation may take some time, depending on the number of stack instances included in the stack set, as well as the number of resources included in each stack. Once the operation has completed, use the following actions to return drift information:   Use  DescribeStackSet  to return detailed information about the stack set, including detailed information about the last completed drift operation performed on the stack set. (Information about drift operations that are in progress is not included.)   Use  ListStackInstances  to return a list of stack instances belonging to the stack set, including the drift status and last drift time checked of each instance.   Use  DescribeStackInstance  to return detailed information about a specific stack instance, including its drift status and last drift time checked.   For more information on performing a drift detection operation on a stack set, see Detecting Unmanaged Changes in Stack Sets.  You can only run a single drift detection operation on a given stack set at one time.  To stop a drift detection stack set operation, use  StopStackSetOperation .

    Args:
        stack_set_name(str): The name of the stack set on which to perform the drift detection operation.
        operation_preferences(Dict, optional): The user-specified preferences for how CloudFormation performs a stack set operation.  For more information on maximum concurrent accounts and failure tolerance, see Stack set operation options. Defaults to None.
        operation_id(str, optional):  The ID of the stack set operation. . Defaults to None.
        call_as(str, optional): [Service-managed permissions] Specifies whether you are acting as an account administrator in the organization's management account or as a delegated administrator in a member account. By default, SELF is specified. Use SELF for stack sets with self-managed permissions.   If you are signed in to the management account, specify SELF.   If you are signed in to a delegated administrator account, specify DELEGATED_ADMIN. Your account must be registered as a delegated administrator in the management account. For more information, see Register a delegated administrator in the CloudFormation User Guide.  . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudformation.stack.set_.drift.detect(
                ctx, stack_set_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudformation.stack.set_.drift.detect stack_set_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudformation",
        operation="detect_stack_set_drift",
        op_kwargs={
            "StackSetName": stack_set_name,
            "OperationPreferences": operation_preferences,
            "OperationId": operation_id,
            "CallAs": call_as,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, game_lift_aws_account_id: str, peer_vpc_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Requests authorization to create or delete a peer connection between the VPC for your Amazon GameLift fleet and a virtual private cloud (VPC) in your AWS account. VPC peering enables the game servers on your fleet to communicate directly with other AWS resources. Once you've received authorization, call CreateVpcPeeringConnection to establish the peering connection. For more information, see VPC Peering with Amazon GameLift Fleets. You can peer with VPCs that are owned by any AWS account you have access to, including the account that you use to manage your Amazon GameLift fleets. You cannot peer with VPCs that are in different Regions. To request authorization to create a connection, call this operation from the AWS account with the VPC that you want to peer to your Amazon GameLift fleet. For example, to enable your game servers to retrieve data from a DynamoDB table, use the account that manages that DynamoDB resource. Identify the following values: (1) The ID of the VPC that you want to peer with, and (2) the ID of the AWS account that you use to manage Amazon GameLift. If successful, VPC peering is authorized for the specified VPC.  To request authorization to delete a connection, call this operation from the AWS account with the VPC that is peered with your Amazon GameLift fleet. Identify the following values: (1) VPC ID that you want to delete the peering connection for, and (2) ID of the AWS account that you use to manage Amazon GameLift.  The authorization remains valid for 24 hours unless it is canceled by a call to DeleteVpcPeeringAuthorization. You must create or delete the peering connection while the authorization is valid.   Related actions   CreateVpcPeeringAuthorization | DescribeVpcPeeringAuthorizations | DeleteVpcPeeringAuthorization | CreateVpcPeeringConnection | DescribeVpcPeeringConnections | DeleteVpcPeeringConnection | All APIs by task

    Args:
        game_lift_aws_account_id(str): A unique identifier for the AWS account that you use to manage your GameLift fleet. You can find your Account ID in the AWS Management Console under account settings.
        peer_vpc_id(str): A unique identifier for a VPC with resources to be accessed by your GameLift fleet. The VPC must be in the same Region as your fleet. To look up a VPC ID, use the VPC Dashboard in the AWS Management Console. Learn more about VPC peering in VPC Peering with GameLift Fleets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.vpc_peering.authorization.create(
                ctx, game_lift_aws_account_id=value, peer_vpc_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.vpc_peering.authorization.create game_lift_aws_account_id=value, peer_vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="create_vpc_peering_authorization",
        op_kwargs={
            "GameLiftAwsAccountId": game_lift_aws_account_id,
            "PeerVpcId": peer_vpc_id,
        },
    )


async def delete(hub, ctx, game_lift_aws_account_id: str, peer_vpc_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a pending VPC peering authorization for the specified VPC. If you need to delete an existing VPC peering connection, call DeleteVpcPeeringConnection.   Related actions   CreateVpcPeeringAuthorization | DescribeVpcPeeringAuthorizations | DeleteVpcPeeringAuthorization | CreateVpcPeeringConnection | DescribeVpcPeeringConnections | DeleteVpcPeeringConnection | All APIs by task

    Args:
        game_lift_aws_account_id(str): A unique identifier for the AWS account that you use to manage your GameLift fleet. You can find your Account ID in the AWS Management Console under account settings.
        peer_vpc_id(str): A unique identifier for a VPC with resources to be accessed by your GameLift fleet. The VPC must be in the same Region as your fleet. To look up a VPC ID, use the VPC Dashboard in the AWS Management Console. Learn more about VPC peering in VPC Peering with GameLift Fleets.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.vpc_peering.authorization.delete(
                ctx, game_lift_aws_account_id=value, peer_vpc_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.vpc_peering.authorization.delete game_lift_aws_account_id=value, peer_vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="delete_vpc_peering_authorization",
        op_kwargs={
            "GameLiftAwsAccountId": game_lift_aws_account_id,
            "PeerVpcId": peer_vpc_id,
        },
    )


async def describe_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves valid VPC peering authorizations that are pending for the AWS account. This operation returns all VPC peering authorizations and requests for peering. This includes those initiated and received by this account.   Related actions   CreateVpcPeeringAuthorization | DescribeVpcPeeringAuthorizations | DeleteVpcPeeringAuthorization | CreateVpcPeeringConnection | DescribeVpcPeeringConnections | DeleteVpcPeeringConnection | All APIs by task


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.vpc_peering.authorization.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.vpc_peering.authorization.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_vpc_peering_authorizations",
        op_kwargs={},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    direct_connect_gateway_id: str = None,
    virtual_interface_id: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the attachments between your Direct Connect gateways and virtual interfaces. You must specify a Direct Connect gateway, a virtual interface, or both. If you specify a Direct Connect gateway, the response contains all virtual interfaces attached to the Direct Connect gateway. If you specify a virtual interface, the response contains all Direct Connect gateways attached to the virtual interface. If you specify both, the response contains the attachment between the Direct Connect gateway and the virtual interface.

    Args:
        direct_connect_gateway_id(str, optional): The ID of the Direct Connect gateway. Defaults to None.
        virtual_interface_id(str, optional): The ID of the virtual interface. Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. If MaxResults is given a value larger than 100, only 100 results are returned. Defaults to None.
        next_token(str, optional): The token provided in the previous call to retrieve the next page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.directconnect.direct_connect_gateway.attachment.describe_all(
                ctx
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.directconnect.direct_connect_gateway.attachment.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="directconnect",
        operation="describe_direct_connect_gateway_attachments",
        op_kwargs={
            "directConnectGatewayId": direct_connect_gateway_id,
            "virtualInterfaceId": virtual_interface_id,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub, ctx, name: str, rule_version: str, rules: List, default_value: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new Cost Category with the requested name and rules.

    Args:
        name(str): The unique name of the Cost Category.
        rule_version(str): The rule schema version in this particular Cost Category.
        rules(List): The Cost Category rules used to categorize costs. For more information, see CostCategoryRule.
        default_value(str, optional): The default value for the cost category. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.cost.category.definition.create(
                ctx, name=value, rule_version=value, rules=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.cost.category.definition.create name=value, rule_version=value, rules=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="create_cost_category_definition",
        op_kwargs={
            "Name": name,
            "RuleVersion": rule_version,
            "Rules": rules,
            "DefaultValue": default_value,
        },
    )


async def delete(hub, ctx, cost_category_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Cost Category. Expenses from this month going forward will no longer be categorized with this Cost Category.

    Args:
        cost_category_arn(str):  The unique identifier for your Cost Category. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.cost.category.definition.delete(ctx, cost_category_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.cost.category.definition.delete cost_category_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="delete_cost_category_definition",
        op_kwargs={"CostCategoryArn": cost_category_arn},
    )


async def describe(hub, ctx, cost_category_arn: str, effective_on: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns the name, ARN, rules, definition, and effective dates of a Cost Category that's defined in the account. You have the option to use EffectiveOn to return a Cost Category that is active on a specific date. If there is no EffectiveOn specified, you’ll see a Cost Category that is effective on the current date. If Cost Category is still effective, EffectiveEnd is omitted in the response.

    Args:
        cost_category_arn(str):  The unique identifier for your Cost Category. .
        effective_on(str, optional):  The date when the Cost Category was effective. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.cost.category.definition.describe(
                ctx, cost_category_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.cost.category.definition.describe cost_category_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="describe_cost_category_definition",
        op_kwargs={"CostCategoryArn": cost_category_arn, "EffectiveOn": effective_on},
    )


async def list_all(
    hub, ctx, effective_on: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the name, ARN, NumberOfRules and effective dates of all Cost Categories defined in the account. You have the option to use EffectiveOn to return a list of Cost Categories that were active on a specific date. If there is no EffectiveOn specified, you’ll see Cost Categories that are effective on the current date. If Cost Category is still effective, EffectiveEnd is omitted in the response. ListCostCategoryDefinitions supports pagination. The request can have a MaxResults range up to 100.

    Args:
        effective_on(str, optional):  The date when the Cost Category was effective. . Defaults to None.
        next_token(str, optional):  The token to retrieve the next set of results. Amazon Web Services provides the token when the response from a previous call has more results than the maximum page size. . Defaults to None.
        max_results(int, optional):  The number of entries a paginated response contains. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.cost.category.definition.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.cost.category.definition.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="list_cost_category_definitions",
        op_kwargs={
            "EffectiveOn": effective_on,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub,
    ctx,
    cost_category_arn: str,
    rule_version: str,
    rules: List,
    default_value: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates an existing Cost Category. Changes made to the Cost Category rules will be used to categorize the current month’s expenses and future expenses. This won’t change categorization for the previous months.

    Args:
        cost_category_arn(str): The unique identifier for your Cost Category.
        rule_version(str): The rule schema version in this particular Cost Category.
        rules(List): The Expression object used to categorize costs. For more information, see CostCategoryRule . .
        default_value(str, optional): The default value for the cost category. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.cost.category.definition.update(
                ctx, cost_category_arn=value, rule_version=value, rules=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.cost.category.definition.update cost_category_arn=value, rule_version=value, rules=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="update_cost_category_definition",
        op_kwargs={
            "CostCategoryArn": cost_category_arn,
            "RuleVersion": rule_version,
            "Rules": rules,
            "DefaultValue": default_value,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, name: str, fleet_id: str) -> None:
    r"""
    **Autogenerated function**

    Deletes a fleet scaling policy. Once deleted, the policy is no longer in force and GameLift removes all record of it. To delete a scaling policy, specify both the scaling policy name and the fleet ID it is associated with. To temporarily suspend scaling policies, call StopFleetActions. This operation suspends all policies for the fleet.  Related actions   DescribeFleetCapacity | UpdateFleetCapacity | DescribeEC2InstanceLimits | PutScalingPolicy | DescribeScalingPolicies | DeleteScalingPolicy | StopFleetActions | StartFleetActions | All APIs by task

    Args:
        name(str): A descriptive label that is associated with a fleet's scaling policy. Policy names do not need to be unique.
        fleet_id(str): A unique identifier for the fleet to be deleted. You can use either the fleet ID or ARN value.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.scaling_policy.delete(ctx, name=value, fleet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.scaling_policy.delete name=value, fleet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="delete_scaling_policy",
        op_kwargs={"Name": name, "FleetId": fleet_id},
    )


async def describe_all(
    hub,
    ctx,
    fleet_id: str,
    status_filter: str = None,
    limit: int = None,
    next_token: str = None,
    location: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves all scaling policies applied to a fleet. To get a fleet's scaling policies, specify the fleet ID. You can filter this request by policy status, such as to retrieve only active scaling policies. Use the pagination parameters to retrieve results as a set of sequential pages. If successful, set of ScalingPolicy objects is returned for the fleet. A fleet may have all of its scaling policies suspended (StopFleetActions). This operation does not affect the status of the scaling policies, which remains ACTIVE. To see whether a fleet's scaling policies are in force or suspended, call DescribeFleetAttributes and check the stopped actions.  Related actions   DescribeFleetCapacity | UpdateFleetCapacity | DescribeEC2InstanceLimits | PutScalingPolicy | DescribeScalingPolicies | DeleteScalingPolicy | StopFleetActions | StartFleetActions | All APIs by task

    Args:
        fleet_id(str): A unique identifier for the fleet to retrieve scaling policies for. You can use either the fleet ID or ARN value.
        status_filter(str, optional): Scaling policy status to filter results on. A scaling policy is only in force when in an ACTIVE status.    ACTIVE -- The scaling policy is currently in force.    UPDATEREQUESTED -- A request to update the scaling policy has been received.    UPDATING -- A change is being made to the scaling policy.    DELETEREQUESTED -- A request to delete the scaling policy has been received.    DELETING -- The scaling policy is being deleted.    DELETED -- The scaling policy has been deleted.    ERROR -- An error occurred in creating the policy. It should be removed and recreated.  . Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.
        location(str, optional):  CONTENT TODO . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.scaling_policy.describe_all(ctx, fleet_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.scaling_policy.describe_all fleet_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_scaling_policies",
        op_kwargs={
            "FleetId": fleet_id,
            "StatusFilter": status_filter,
            "Limit": limit,
            "NextToken": next_token,
            "Location": location,
        },
    )


async def put(
    hub,
    ctx,
    name: str,
    fleet_id: str,
    metric_name: str,
    scaling_adjustment: int = None,
    scaling_adjustment_type: str = None,
    threshold: float = None,
    comparison_operator: str = None,
    evaluation_periods: int = None,
    policy_type: str = None,
    target_configuration: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates a scaling policy for a fleet. Scaling policies are used to automatically scale a fleet's hosting capacity to meet player demand. An active scaling policy instructs Amazon GameLift to track a fleet metric and automatically change the fleet's capacity when a certain threshold is reached. There are two types of scaling policies: target-based and rule-based. Use a target-based policy to quickly and efficiently manage fleet scaling; this option is the most commonly used. Use rule-based policies when you need to exert fine-grained control over auto-scaling.  Fleets can have multiple scaling policies of each type in force at the same time; you can have one target-based policy, one or multiple rule-based scaling policies, or both. We recommend caution, however, because multiple auto-scaling policies can have unintended consequences. You can temporarily suspend all scaling policies for a fleet by calling StopFleetActions with the fleet action AUTO_SCALING. To resume scaling policies, call StartFleetActions with the same fleet action. To stop just one scaling policy--or to permanently remove it, you must delete the policy with DeleteScalingPolicy. Learn more about how to work with auto-scaling in Set Up Fleet Automatic Scaling.  Target-based policy  A target-based policy tracks a single metric: PercentAvailableGameSessions. This metric tells us how much of a fleet's hosting capacity is ready to host game sessions but is not currently in use. This is the fleet's buffer; it measures the additional player demand that the fleet could handle at current capacity. With a target-based policy, you set your ideal buffer size and leave it to Amazon GameLift to take whatever action is needed to maintain that target.  For example, you might choose to maintain a 10% buffer for a fleet that has the capacity to host 100 simultaneous game sessions. This policy tells Amazon GameLift to take action whenever the fleet's available capacity falls below or rises above 10 game sessions. Amazon GameLift will start new instances or stop unused instances in order to return to the 10% buffer.  To create or update a target-based policy, specify a fleet ID and name, and set the policy type to "TargetBased". Specify the metric to track (PercentAvailableGameSessions) and reference a TargetConfiguration object with your desired buffer value. Exclude all other parameters. On a successful request, the policy name is returned. The scaling policy is automatically in force as soon as it's successfully created. If the fleet's auto-scaling actions are temporarily suspended, the new policy will be in force once the fleet actions are restarted.  Rule-based policy  A rule-based policy tracks specified fleet metric, sets a threshold value, and specifies the type of action to initiate when triggered. With a rule-based policy, you can select from several available fleet metrics. Each policy specifies whether to scale up or scale down (and by how much), so you need one policy for each type of action.  For example, a policy may make the following statement: "If the percentage of idle instances is greater than 20% for more than 15 minutes, then reduce the fleet capacity by 10%." A policy's rule statement has the following structure: If [MetricName] is [ComparisonOperator] [Threshold] for [EvaluationPeriods] minutes, then [ScalingAdjustmentType] to/by [ScalingAdjustment]. To implement the example, the rule statement would look like this: If [PercentIdleInstances] is [GreaterThanThreshold] [20] for [15] minutes, then [PercentChangeInCapacity] to/by [10]. To create or update a scaling policy, specify a unique combination of name and fleet ID, and set the policy type to "RuleBased". Specify the parameter values for a policy rule statement. On a successful request, the policy name is returned. Scaling policies are automatically in force as soon as they're successfully created. If the fleet's auto-scaling actions are temporarily suspended, the new policy will be in force once the fleet actions are restarted.  Related actions   DescribeFleetCapacity | UpdateFleetCapacity | DescribeEC2InstanceLimits | PutScalingPolicy | DescribeScalingPolicies | DeleteScalingPolicy | StopFleetActions | StartFleetActions | All APIs by task

    Args:
        name(str): A descriptive label that is associated with a fleet's scaling policy. Policy names do not need to be unique. A fleet can have only one scaling policy with the same name.
        fleet_id(str): A unique identifier for the fleet to apply this policy to. You can use either the fleet ID or ARN value. The fleet cannot be in any of the following statuses: ERROR or DELETING.
        scaling_adjustment(int, optional): Amount of adjustment to make, based on the scaling adjustment type. Defaults to None.
        scaling_adjustment_type(str, optional): The type of adjustment to make to a fleet's instance count (see FleetCapacity):    ChangeInCapacity -- add (or subtract) the scaling adjustment value from the current instance count. Positive values scale up while negative values scale down.    ExactCapacity -- set the instance count to the scaling adjustment value.    PercentChangeInCapacity -- increase or reduce the current instance count by the scaling adjustment, read as a percentage. Positive values scale up while negative values scale down; for example, a value of "-10" scales the fleet down by 10%.  . Defaults to None.
        threshold(float, optional): Metric value used to trigger a scaling event. Defaults to None.
        comparison_operator(str, optional): Comparison operator to use when measuring the metric against the threshold value. Defaults to None.
        evaluation_periods(int, optional): Length of time (in minutes) the metric must be at or beyond the threshold before a scaling event is triggered. Defaults to None.
        metric_name(str): Name of the Amazon GameLift-defined metric that is used to trigger a scaling adjustment. For detailed descriptions of fleet metrics, see Monitor Amazon GameLift with Amazon CloudWatch.     ActivatingGameSessions -- Game sessions in the process of being created.    ActiveGameSessions -- Game sessions that are currently running.    ActiveInstances -- Fleet instances that are currently running at least one game session.    AvailableGameSessions -- Additional game sessions that fleet could host simultaneously, given current capacity.    AvailablePlayerSessions -- Empty player slots in currently active game sessions. This includes game sessions that are not currently accepting players. Reserved player slots are not included.    CurrentPlayerSessions -- Player slots in active game sessions that are being used by a player or are reserved for a player.     IdleInstances -- Active instances that are currently hosting zero game sessions.     PercentAvailableGameSessions -- Unused percentage of the total number of game sessions that a fleet could host simultaneously, given current capacity. Use this metric for a target-based scaling policy.    PercentIdleInstances -- Percentage of the total number of active instances that are hosting zero game sessions.    QueueDepth -- Pending game session placement requests, in any queue, where the current fleet is the top-priority destination.    WaitTime -- Current wait time for pending game session placement requests, in any queue, where the current fleet is the top-priority destination.   .
        policy_type(str, optional): The type of scaling policy to create. For a target-based policy, set the parameter MetricName to 'PercentAvailableGameSessions' and specify a TargetConfiguration. For a rule-based policy set the following parameters: MetricName, ComparisonOperator, Threshold, EvaluationPeriods, ScalingAdjustmentType, and ScalingAdjustment. Defaults to None.
        target_configuration(Dict, optional): An object that contains settings for a target-based scaling policy. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.scaling_policy.put(
                ctx, name=value, fleet_id=value, metric_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.scaling_policy.put name=value, fleet_id=value, metric_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="put_scaling_policy",
        op_kwargs={
            "Name": name,
            "FleetId": fleet_id,
            "ScalingAdjustment": scaling_adjustment,
            "ScalingAdjustmentType": scaling_adjustment_type,
            "Threshold": threshold,
            "ComparisonOperator": comparison_operator,
            "EvaluationPeriods": evaluation_periods,
            "MetricName": metric_name,
            "PolicyType": policy_type,
            "TargetConfiguration": target_configuration,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def associate(hub, ctx, alias_id: str, resource_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Associates the specified connection alias with the specified directory to enable cross-Region redirection. For more information, see  Cross-Region Redirection for Amazon WorkSpaces.  Before performing this operation, call  DescribeConnectionAliases to make sure that the current state of the connection alias is CREATED.

    Args:
        alias_id(str): The identifier of the connection alias.
        resource_id(str): The identifier of the directory to associate the connection alias with.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.connection_alias.init.associate(
                ctx, alias_id=value, resource_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.connection_alias.init.associate alias_id=value, resource_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="associate_connection_alias",
        op_kwargs={"AliasId": alias_id, "ResourceId": resource_id},
    )


async def create(hub, ctx, connection_string: str, tags: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates the specified connection alias for use with cross-Region redirection. For more information, see  Cross-Region Redirection for Amazon WorkSpaces.

    Args:
        connection_string(str): A connection string in the form of a fully qualified domain name (FQDN), such as www.example.com.  After you create a connection string, it is always associated to your AWS account. You cannot recreate the same connection string with a different account, even if you delete all instances of it from the original account. The connection string is globally reserved for your account. .
        tags(List, optional): The tags to associate with the connection alias. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.connection_alias.init.create(
                ctx, connection_string=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.connection_alias.init.create connection_string=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="create_connection_alias",
        op_kwargs={"ConnectionString": connection_string, "Tags": tags},
    )


async def delete(hub, ctx, alias_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified connection alias. For more information, see  Cross-Region Redirection for Amazon WorkSpaces.   If you will no longer be using a fully qualified domain name (FQDN) as the registration code for your WorkSpaces users, you must take certain precautions to prevent potential security issues. For more information, see  Security Considerations if You Stop Using Cross-Region Redirection.   To delete a connection alias that has been shared, the shared account must first disassociate the connection alias from any directories it has been associated with. Then you must unshare the connection alias from the account it has been shared with. You can delete a connection alias only after it is no longer shared with any accounts or associated with any directories.

    Args:
        alias_id(str): The identifier of the connection alias to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.connection_alias.init.delete(ctx, alias_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.connection_alias.init.delete alias_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="delete_connection_alias",
        op_kwargs={"AliasId": alias_id},
    )


async def disassociate(hub, ctx, alias_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Disassociates a connection alias from a directory. Disassociating a connection alias disables cross-Region redirection between two directories in different AWS Regions. For more information, see  Cross-Region Redirection for Amazon WorkSpaces.  Before performing this operation, call  DescribeConnectionAliases to make sure that the current state of the connection alias is CREATED.

    Args:
        alias_id(str): The identifier of the connection alias to disassociate.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.workspace.connection_alias.init.disassociate(
                ctx, alias_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.workspace.connection_alias.init.disassociate alias_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="workspaces",
        operation="disassociate_connection_alias",
        op_kwargs={"AliasId": alias_id},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub, ctx, placement_name: str, project_name: str, attributes: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an empty placement.

    Args:
        placement_name(str): The name of the placement to be created.
        project_name(str): The name of the project in which to create the placement.
        attributes(Dict, optional): Optional user-defined key/value pairs providing contextual data (such as location or function) for the placement. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_project.placement.create(
                ctx, placement_name=value, project_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_project.placement.create placement_name=value, project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-projects",
        operation="create_placement",
        op_kwargs={
            "placementName": placement_name,
            "projectName": project_name,
            "attributes": attributes,
        },
    )


async def delete(hub, ctx, placement_name: str, project_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a placement. To delete a placement, it must not have any devices associated with it.  When you delete a placement, all associated data becomes irretrievable.

    Args:
        placement_name(str): The name of the empty placement to delete.
        project_name(str): The project containing the empty placement to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_project.placement.delete(
                ctx, placement_name=value, project_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_project.placement.delete placement_name=value, project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-projects",
        operation="delete_placement",
        op_kwargs={"placementName": placement_name, "projectName": project_name},
    )


async def describe(hub, ctx, placement_name: str, project_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a placement in a project.

    Args:
        placement_name(str): The name of the placement within a project.
        project_name(str): The project containing the placement to be described.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_project.placement.describe(
                ctx, placement_name=value, project_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_project.placement.describe placement_name=value, project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-projects",
        operation="describe_placement",
        op_kwargs={"placementName": placement_name, "projectName": project_name},
    )


async def list_all(
    hub, ctx, project_name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the placement(s) of a project.

    Args:
        project_name(str): The project containing the placements to be listed.
        next_token(str, optional): The token to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return per request. If not set, a default value of 100 is used. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_project.placement.list_all(ctx, project_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_project.placement.list_all project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-projects",
        operation="list_placements",
        op_kwargs={
            "projectName": project_name,
            "nextToken": next_token,
            "maxResults": max_results,
        },
    )


async def update(
    hub, ctx, placement_name: str, project_name: str, attributes: Dict = None
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a placement with the given attributes. To clear an attribute, pass an empty value (i.e., "").

    Args:
        placement_name(str): The name of the placement to update.
        project_name(str): The name of the project containing the placement to be updated.
        attributes(Dict, optional): The user-defined object of attributes used to update the placement. The maximum number of key/value pairs is 50. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot1click_project.placement.update(
                ctx, placement_name=value, project_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot1click_project.placement.update placement_name=value, project_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot1click-projects",
        operation="update_placement",
        op_kwargs={
            "placementName": placement_name,
            "projectName": project_name,
            "attributes": attributes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    workload_id: str,
    shared_with: str,
    permission_type: str,
    client_request_token: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Create a workload share. The owner of a workload can share it with other AWS accounts and IAM users in the same AWS Region. Shared access to a workload is not removed until the workload invitation is deleted. For more information, see Sharing a Workload in the AWS Well-Architected Tool User Guide.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        shared_with(str): The AWS account ID or IAM role with which the workload is shared.
        permission_type(str): Permission granted on a workload share.
        client_request_token(str): A unique case-sensitive string used to ensure that this request is idempotent (executes only once). You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after it has completed successfully, the result of the original request is returned.   This token is listed as required, however, if you do not specify it, the AWS SDKs automatically generate one for you. If you are not using the AWS SDK or the AWS CLI, you must provide this token or the request will fail. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.workload.share.create(
                ctx,
                workload_id=value,
                shared_with=value,
                permission_type=value,
                client_request_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.workload.share.create workload_id=value, shared_with=value, permission_type=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="create_workload_share",
        op_kwargs={
            "WorkloadId": workload_id,
            "SharedWith": shared_with,
            "PermissionType": permission_type,
            "ClientRequestToken": client_request_token,
        },
    )


async def delete(
    hub, ctx, share_id: str, workload_id: str, client_request_token: str
) -> None:
    r"""
    **Autogenerated function**

    Delete a workload share.

    Args:
        share_id(str): The ID associated with the workload share.
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        client_request_token(str): A unique case-sensitive string used to ensure that this request is idempotent (executes only once). You should not reuse the same token for other requests. If you retry a request with the same client request token and the same parameters after it has completed successfully, the result of the original request is returned.   This token is listed as required, however, if you do not specify it, the AWS SDKs automatically generate one for you. If you are not using the AWS SDK or the AWS CLI, you must provide this token or the request will fail. .
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.workload.share.delete(
                ctx, share_id=value, workload_id=value, client_request_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.workload.share.delete share_id=value, workload_id=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="delete_workload_share",
        op_kwargs={
            "ShareId": share_id,
            "WorkloadId": workload_id,
            "ClientRequestToken": client_request_token,
        },
    )


async def list_all(
    hub,
    ctx,
    workload_id: str,
    shared_with_prefix: str = None,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List the workload shares associated with the workload.

    Args:
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        shared_with_prefix(str, optional): The AWS account ID or IAM role with which the workload is shared. Defaults to None.
        next_token(str, optional): The token to use to retrieve the next set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return for this request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.workload.share.list_all(ctx, workload_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.workload.share.list_all workload_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="list_workload_shares",
        op_kwargs={
            "WorkloadId": workload_id,
            "SharedWithPrefix": shared_with_prefix,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )


async def update(
    hub, ctx, share_id: str, workload_id: str, permission_type: str
) -> Dict:
    r"""
    **Autogenerated function**

    Update a workload share.

    Args:
        share_id(str): The ID associated with the workload share.
        workload_id(str): The ID assigned to the workload. This ID is unique within an AWS Region.
        permission_type(str): Permission granted on a workload share.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.workload.share.update(
                ctx, share_id=value, workload_id=value, permission_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.workload.share.update share_id=value, workload_id=value, permission_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="update_workload_share",
        op_kwargs={
            "ShareId": share_id,
            "WorkloadId": workload_id,
            "PermissionType": permission_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub, ctx, auto_scaling_group_name: str, force_delete: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the warm pool for the specified Auto Scaling group. For more information, see Warm pools for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        force_delete(bool, optional): Specifies that the warm pool is to be deleted along with all of its associated instances, without waiting for all instances to be terminated. This parameter also deletes any outstanding lifecycle actions associated with the warm pool instances. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.warm_pool.delete(ctx, auto_scaling_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.warm_pool.delete auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="delete_warm_pool",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "ForceDelete": force_delete,
        },
    )


async def describe(
    hub,
    ctx,
    auto_scaling_group_name: str,
    max_records: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a warm pool and its instances. For more information, see Warm pools for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        max_records(int, optional): The maximum number of instances to return with this call. The maximum value is 50. Defaults to None.
        next_token(str, optional): The token for the next set of instances to return. (You received this token from a previous call.). Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.warm_pool.describe(
                ctx, auto_scaling_group_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.warm_pool.describe auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="describe_warm_pool",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "MaxRecords": max_records,
            "NextToken": next_token,
        },
    )


async def put(
    hub,
    ctx,
    auto_scaling_group_name: str,
    max_group_prepared_capacity: int = None,
    min_size: int = None,
    pool_state: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates or updates a warm pool for the specified Auto Scaling group. A warm pool is a pool of pre-initialized EC2 instances that sits alongside the Auto Scaling group. Whenever your application needs to scale out, the Auto Scaling group can draw on the warm pool to meet its new desired capacity. For more information and example configurations, see Warm pools for Amazon EC2 Auto Scaling in the Amazon EC2 Auto Scaling User Guide. This operation must be called from the Region in which the Auto Scaling group was created. This operation cannot be called on an Auto Scaling group that has a mixed instances policy or a launch template or launch configuration that requests Spot Instances. You can view the instances in the warm pool using the DescribeWarmPool API call. If you are no longer using a warm pool, you can delete it by calling the DeleteWarmPool API.

    Args:
        auto_scaling_group_name(str): The name of the Auto Scaling group.
        max_group_prepared_capacity(int, optional): Specifies the maximum number of instances that are allowed to be in the warm pool or in any state except Terminated for the Auto Scaling group. This is an optional property. Specify it only if you do not want the warm pool size to be determined by the difference between the group's maximum capacity and its desired capacity.   If a value for MaxGroupPreparedCapacity is not specified, Amazon EC2 Auto Scaling launches and maintains the difference between the group's maximum capacity and its desired capacity. If you specify a value for MaxGroupPreparedCapacity, Amazon EC2 Auto Scaling uses the difference between the MaxGroupPreparedCapacity and the desired capacity instead.  The size of the warm pool is dynamic. Only when MaxGroupPreparedCapacity and MinSize are set to the same value does the warm pool have an absolute size.  If the desired capacity of the Auto Scaling group is higher than the MaxGroupPreparedCapacity, the capacity of the warm pool is 0, unless you specify a value for MinSize. To remove a value that you previously set, include the property but specify -1 for the value. . Defaults to None.
        min_size(int, optional): Specifies the minimum number of instances to maintain in the warm pool. This helps you to ensure that there is always a certain number of warmed instances available to handle traffic spikes. Defaults to 0 if not specified. Defaults to None.
        pool_state(str, optional): Sets the instance state to transition to after the lifecycle actions are complete. Default is Stopped. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.autoscaling.warm_pool.put(ctx, auto_scaling_group_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.autoscaling.warm_pool.put auto_scaling_group_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="autoscaling",
        operation="put_warm_pool",
        op_kwargs={
            "AutoScalingGroupName": auto_scaling_group_name,
            "MaxGroupPreparedCapacity": max_group_prepared_capacity,
            "MinSize": min_size,
            "PoolState": pool_state,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def attach(
    hub,
    ctx,
    gateway_arn: str,
    volume_arn: str,
    network_interface_id: str,
    target_name: str = None,
    disk_id: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Connects a volume to an iSCSI connection and then attaches the volume to the specified gateway. Detaching and attaching a volume enables you to recover your data from one gateway to a different gateway without creating a snapshot. It also makes it easier to move your volumes from an on-premises gateway to a gateway hosted on an Amazon EC2 instance.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway that you want to attach the volume to.
        target_name(str, optional): The name of the iSCSI target used by an initiator to connect to a volume and used as a suffix for the target ARN. For example, specifying TargetName as myvolume results in the target ARN of arn:aws:storagegateway:us-east-2:111122223333:gateway/sgw-12A3456B/target/iqn.1997-05.com.amazon:myvolume. The target name must be unique across all volumes on a gateway. If you don't specify a value, Storage Gateway uses the value that was previously used for this volume as the new target name. Defaults to None.
        volume_arn(str): The Amazon Resource Name (ARN) of the volume to attach to the specified gateway.
        network_interface_id(str): The network interface of the gateway on which to expose the iSCSI target. Only IPv4 addresses are accepted. Use DescribeGatewayInformation to get a list of the network interfaces available on a gateway. Valid Values: A valid IP address.
        disk_id(str, optional): The unique device ID or other distinguishing data that identifies the local disk used to create the volume. This value is only required when you are attaching a stored volume. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.volume.init.attach(
                ctx, gateway_arn=value, volume_arn=value, network_interface_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.volume.init.attach gateway_arn=value, volume_arn=value, network_interface_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="attach_volume",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "TargetName": target_name,
            "VolumeARN": volume_arn,
            "NetworkInterfaceId": network_interface_id,
            "DiskId": disk_id,
        },
    )


async def delete(hub, ctx, volume_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified storage volume that you previously created using the CreateCachediSCSIVolume or CreateStorediSCSIVolume API. This operation is only supported in the cached volume and stored volume types. For stored volume gateways, the local disk that was configured as the storage volume is not deleted. You can reuse the local disk to create another storage volume. Before you delete a volume, make sure there are no iSCSI connections to the volume you are deleting. You should also make sure there is no snapshot in progress. You can use the Amazon Elastic Compute Cloud (Amazon EC2) API to query snapshots on the volume you are deleting and check the snapshot status. For more information, go to DescribeSnapshots in the Amazon Elastic Compute Cloud API Reference. In the request, you must provide the Amazon Resource Name (ARN) of the storage volume you want to delete.

    Args:
        volume_arn(str): The Amazon Resource Name (ARN) of the volume. Use the ListVolumes operation to return a list of gateway volumes.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.volume.init.delete(ctx, volume_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.volume.init.delete volume_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="delete_volume",
        op_kwargs={"VolumeARN": volume_arn},
    )


async def detach(hub, ctx, volume_arn: str, force_detach: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Disconnects a volume from an iSCSI connection and then detaches the volume from the specified gateway. Detaching and attaching a volume enables you to recover your data from one gateway to a different gateway without creating a snapshot. It also makes it easier to move your volumes from an on-premises gateway to a gateway hosted on an Amazon EC2 instance. This operation is only supported in the volume gateway type.

    Args:
        volume_arn(str): The Amazon Resource Name (ARN) of the volume to detach from the gateway.
        force_detach(bool, optional): Set to true to forcibly remove the iSCSI connection of the target volume and detach the volume. The default is false. If this value is set to false, you must manually disconnect the iSCSI connection from the target volume. Valid Values: true | false . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.volume.init.detach(ctx, volume_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.volume.init.detach volume_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="detach_volume",
        op_kwargs={"VolumeARN": volume_arn, "ForceDetach": force_detach},
    )


async def list_all(
    hub, ctx, gateway_arn: str = None, marker: str = None, limit: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the iSCSI stored volumes of a gateway. Results are sorted by volume ARN. The response includes only the volume ARNs. If you want additional volume information, use the DescribeStorediSCSIVolumes or the DescribeCachediSCSIVolumes API. The operation supports pagination. By default, the operation returns a maximum of up to 100 volumes. You can optionally specify the Limit field in the body to limit the number of volumes in the response. If the number of volumes returned in the response is truncated, the response includes a Marker field. You can use this Marker value in your subsequent request to retrieve the next set of volumes. This operation is only supported in the cached volume and stored volume gateway types.

    Args:
        gateway_arn(str, optional): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region. Defaults to None.
        marker(str, optional): A string that indicates the position at which to begin the returned list of volumes. Obtain the marker from the response of a previous List iSCSI Volumes request. Defaults to None.
        limit(int, optional): Specifies that the list of volumes returned be limited to the specified number of items. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.volume.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.volume.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="list_volumes",
        op_kwargs={"GatewayARN": gateway_arn, "Marker": marker, "Limit": limit},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    description: str = None,
    options: Dict = None,
    tag_specifications: List = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a transit gateway. You can use a transit gateway to interconnect your virtual private clouds (VPC) and on-premises networks. After the transit gateway enters the available state, you can attach your VPCs and VPN connections to the transit gateway. To attach your VPCs, use CreateTransitGatewayVpcAttachment. To attach a VPN connection, use CreateCustomerGateway to create a customer gateway and specify the ID of the customer gateway and the ID of the transit gateway in a call to CreateVpnConnection. When you create a transit gateway, we create a default transit gateway route table and use it as the default association route table and the default propagation route table. You can use CreateTransitGatewayRouteTable to create additional transit gateway route tables. If you disable automatic route propagation, we do not create a default transit gateway route table. You can use EnableTransitGatewayRouteTablePropagation to propagate routes from a resource attachment to a transit gateway route table. If you disable automatic associations, you can use AssociateTransitGatewayRouteTable to associate a resource attachment with a transit gateway route table.

    Args:
        description(str, optional): A description of the transit gateway. Defaults to None.
        options(Dict, optional): The transit gateway options. Defaults to None.
        tag_specifications(List, optional): The tags to apply to the transit gateway. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.init.create(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.init.create
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="create_transit_gateway",
        op_kwargs={
            "Description": description,
            "Options": options,
            "TagSpecifications": tag_specifications,
            "DryRun": dry_run,
        },
    )


async def delete(hub, ctx, transit_gateway_id: str, dry_run: bool = None) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified transit gateway.

    Args:
        transit_gateway_id(str): The ID of the transit gateway.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.init.delete(ctx, transit_gateway_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.init.delete transit_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="delete_transit_gateway",
        op_kwargs={"TransitGatewayId": transit_gateway_id, "DryRun": dry_run},
    )


async def describe_all(
    hub,
    ctx,
    transit_gateway_ids: List = None,
    filters: List = None,
    max_results: int = None,
    next_token: str = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes one or more transit gateways. By default, all transit gateways are described. Alternatively, you can filter the results.

    Args:
        transit_gateway_ids(List, optional): The IDs of the transit gateways. Defaults to None.
        filters(List, optional): One or more filters. The possible values are:    options.propagation-default-route-table-id - The ID of the default propagation route table.    options.amazon-side-asn - The private ASN for the Amazon side of a BGP session.    options.association-default-route-table-id - The ID of the default association route table.    options.auto-accept-shared-attachments - Indicates whether there is automatic acceptance of attachment requests (enable | disable).    options.default-route-table-association - Indicates whether resource attachments are automatically associated with the default association route table (enable | disable).    options.default-route-table-propagation - Indicates whether resource attachments automatically propagate routes to the default propagation route table (enable | disable).    options.dns-support - Indicates whether DNS support is enabled (enable | disable).    options.vpn-ecmp-support - Indicates whether Equal Cost Multipath Protocol support is enabled (enable | disable).    owner-id - The ID of the AWS account that owns the transit gateway.    state - The state of the transit gateway (available | deleted | deleting | modifying | pending).    transit-gateway-id - The ID of the transit gateway.  . Defaults to None.
        max_results(int, optional): The maximum number of results to return with a single call. To retrieve the remaining results, make another call with the returned nextToken value. Defaults to None.
        next_token(str, optional): The token for the next page of results. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_transit_gateways",
        op_kwargs={
            "TransitGatewayIds": transit_gateway_ids,
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
            "DryRun": dry_run,
        },
    )


async def modify(
    hub,
    ctx,
    transit_gateway_id: str,
    description: str = None,
    options: Dict = None,
    dry_run: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Modifies the specified transit gateway. When you modify a transit gateway, the modified options are applied to new transit gateway attachments only. Your existing transit gateway attachments are not modified.

    Args:
        transit_gateway_id(str): The ID of the transit gateway.
        description(str, optional): The description for the transit gateway. Defaults to None.
        options(Dict, optional): The options to modify. Defaults to None.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.transit_gateway.init.modify(ctx, transit_gateway_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.transit_gateway.init.modify transit_gateway_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="modify_transit_gateway",
        op_kwargs={
            "TransitGatewayId": transit_gateway_id,
            "Description": description,
            "Options": options,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def attach(hub, ctx, thing_name: str, principal: str) -> Dict:
    r"""
    **Autogenerated function**

    Attaches the specified principal to the specified thing. A principal can be X.509 certificates, IAM users, groups, and roles, Amazon Cognito identities or federated identities.

    Args:
        thing_name(str): The name of the thing.
        principal(str): The principal, which can be a certificate ARN (as returned from the CreateCertificate operation) or an Amazon Cognito ID.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.principal.attach(
                ctx, thing_name=value, principal=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.principal.attach thing_name=value, principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="attach_thing_principal",
        op_kwargs={"thingName": thing_name, "principal": principal},
    )


async def detach(hub, ctx, thing_name: str, principal: str) -> Dict:
    r"""
    **Autogenerated function**

    Detaches the specified principal from the specified thing. A principal can be X.509 certificates, IAM users, groups, and roles, Amazon Cognito identities or federated identities.  This call is asynchronous. It might take several seconds for the detachment to propagate.

    Args:
        thing_name(str): The name of the thing.
        principal(str): If the principal is a certificate, this value must be ARN of the certificate. If the principal is an Amazon Cognito identity, this value must be the ID of the Amazon Cognito identity.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.principal.detach(
                ctx, thing_name=value, principal=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.principal.detach thing_name=value, principal=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="detach_thing_principal",
        op_kwargs={"thingName": thing_name, "principal": principal},
    )


async def list_all(
    hub, ctx, thing_name: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the principals associated with the specified thing. A principal can be X.509 certificates, IAM users, groups, and roles, Amazon Cognito identities or federated identities.

    Args:
        next_token(str, optional): To retrieve the next set of results, the nextToken value from a previous response; otherwise null to receive the first set of results. Defaults to None.
        max_results(int, optional): The maximum number of results to return in this operation. Defaults to None.
        thing_name(str): The name of the thing.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.thing.principal.list_all(ctx, thing_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.thing.principal.list_all thing_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="list_thing_principals",
        op_kwargs={
            "nextToken": next_token,
            "maxResults": max_results,
            "thingName": thing_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def register(hub, ctx, certificate_pem: str, status: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Register a certificate that does not have a certificate authority (CA).

    Args:
        certificate_pem(str): The certificate data, in PEM format.
        status(str, optional): The status of the register certificate request. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.iot.certificate.without_ca.register(ctx, certificate_pem=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.iot.certificate.without_ca.register certificate_pem=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="iot",
        operation="register_certificate_without_ca",
        op_kwargs={"certificatePem": certificate_pem, "status": status},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, config_data: Dict, name: str, tags: Dict = None) -> Dict:
    r"""
    **Autogenerated function**

    Creates a Config with the specified configData parameters. Only one type of configData can be specified.

    Args:
        config_data(Dict): Parameters of a Config.
        name(str): Name of a Config.
        tags(Dict, optional): Tags assigned to a Config. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.config.create(ctx, config_data=value, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.config.create config_data=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="create_config",
        op_kwargs={"configData": config_data, "name": name, "tags": tags},
    )


async def delete(hub, ctx, config_id: str, config_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a Config.

    Args:
        config_id(str): UUID of a Config.
        config_type(str): Type of a Config.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.config.delete(
                ctx, config_id=value, config_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.config.delete config_id=value, config_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="delete_config",
        op_kwargs={"configId": config_id, "configType": config_type},
    )


async def get(hub, ctx, config_id: str, config_type: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns Config information. Only one Config response can be returned.

    Args:
        config_id(str): UUID of a Config.
        config_type(str): Type of a Config.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.config.get(
                ctx, config_id=value, config_type=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.config.get config_id=value, config_type=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="get_config",
        op_kwargs={"configId": config_id, "configType": config_type},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of Config objects.

    Args:
        max_results(int, optional): Maximum number of Configs returned. Defaults to None.
        next_token(str, optional): Next token returned in the request of a previous ListConfigs call. Used to get the next page of results. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.config.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.config.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="list_configs",
        op_kwargs={"maxResults": max_results, "nextToken": next_token},
    )


async def update(
    hub, ctx, config_data: Dict, config_id: str, config_type: str, name: str
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the Config used when scheduling contacts. Updating a Config will not update the execution parameters for existing future contacts scheduled with this Config.

    Args:
        config_data(Dict): Parameters of a Config.
        config_id(str): UUID of a Config.
        config_type(str): Type of a Config.
        name(str): Name of a Config.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.groundstation.config.update(
                ctx, config_data=value, config_id=value, config_type=value, name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.groundstation.config.update config_data=value, config_id=value, config_type=value, name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="groundstation",
        operation="update_config",
        op_kwargs={
            "configData": config_data,
            "configId": config_id,
            "configType": config_type,
            "name": name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def build(hub, ctx, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Indexes the search suggestions. For more information, see Configuring Suggesters in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.suggester.build(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.suggester.build domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="build_suggesters",
        op_kwargs={"DomainName": domain_name},
    )


async def define(hub, ctx, domain_name: str, suggester: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Configures a suggester for a domain. A suggester enables you to display possible matches before users finish typing their queries. When you configure a suggester, you must specify the name of the text field you want to search for possible matches and a unique name for the suggester. For more information, see Getting Search Suggestions in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        suggester(Dict): Configuration information for a search suggester. Each suggester has a unique name and specifies the text field you want to use for suggestions. The following options can be configured for a suggester: FuzzyMatching, SortExpression. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.suggester.define(
                ctx, domain_name=value, suggester=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.suggester.define domain_name=value, suggester=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="define_suggester",
        op_kwargs={"DomainName": domain_name, "Suggester": suggester},
    )


async def delete(hub, ctx, domain_name: str, suggester_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a suggester. For more information, see Getting Search Suggestions in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): A string that represents the name of a domain. Domain names are unique across the domains owned by an account within an AWS region. Domain names start with a letter or number and can contain the following characters: a-z (lowercase), 0-9, and - (hyphen).
        suggester_name(str): Specifies the name of the suggester you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.suggester.delete(
                ctx, domain_name=value, suggester_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.suggester.delete domain_name=value, suggester_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="delete_suggester",
        op_kwargs={"DomainName": domain_name, "SuggesterName": suggester_name},
    )


async def describe_all(
    hub, ctx, domain_name: str, suggester_names: List = None, deployed: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the suggesters configured for a domain. A suggester enables you to display possible matches before users finish typing their queries. Can be limited to specific suggesters by name. By default, shows all suggesters and includes any pending changes to the configuration. Set the Deployed option to true to show the active configuration and exclude pending changes. For more information, see Getting Search Suggestions in the Amazon CloudSearch Developer Guide.

    Args:
        domain_name(str): The name of the domain you want to describe.
        suggester_names(List, optional): The suggesters you want to describe. Defaults to None.
        deployed(bool, optional): Whether to display the deployed configuration (true) or include any pending changes (false). Defaults to false. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.cloudsearch.suggester.describe_all(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.cloudsearch.suggester.describe_all domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="cloudsearch",
        operation="describe_suggesters",
        op_kwargs={
            "DomainName": domain_name,
            "SuggesterNames": suggester_names,
            "Deployed": deployed,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def list_all(
    hub, ctx, resource_arn: str, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of alerts for the given resource.

    Args:
        max_results(int, optional): Upper bound on number of records to return. The maximum number of results is 100. Defaults to None.
        next_token(str, optional): Pagination token from the GET list request. Use the token to fetch the next page of results. Defaults to None.
        resource_arn(str): The Amazon Resource Name (ARN) of the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.mediatailor.alert.list_all(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.mediatailor.alert.list_all resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="mediatailor",
        operation="list_alerts",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "ResourceArn": resource_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    source_domain_info: Dict,
    destination_domain_info: Dict,
    connection_alias: str,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new cross-cluster search connection from a source domain to a destination domain.

    Args:
        source_domain_info(Dict): Specifies the DomainInformation for the source Elasticsearch domain.
        destination_domain_info(Dict): Specifies the DomainInformation for the destination Elasticsearch domain.
        connection_alias(str): Specifies the connection alias that will be used by the customer for this connection.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.outbound_cross_cluster_search_connection.create(
                ctx, source_domain_info=value, destination_domain_info=value, connection_alias=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.outbound_cross_cluster_search_connection.create source_domain_info=value, destination_domain_info=value, connection_alias=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="create_outbound_cross_cluster_search_connection",
        op_kwargs={
            "SourceDomainInfo": source_domain_info,
            "DestinationDomainInfo": destination_domain_info,
            "ConnectionAlias": connection_alias,
        },
    )


async def delete(hub, ctx, cross_cluster_search_connection_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Allows the source domain owner to delete an existing outbound cross-cluster search connection.

    Args:
        cross_cluster_search_connection_id(str): The id of the outbound connection that you want to permanently delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.outbound_cross_cluster_search_connection.delete(
                ctx, cross_cluster_search_connection_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.outbound_cross_cluster_search_connection.delete cross_cluster_search_connection_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="delete_outbound_cross_cluster_search_connection",
        op_kwargs={
            "CrossClusterSearchConnectionId": cross_cluster_search_connection_id
        },
    )


async def describe_all(
    hub, ctx, filters: List = None, max_results: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists all the outbound cross-cluster search connections for a source domain.

    Args:
        filters(List, optional):  A list of filters used to match properties for outbound cross-cluster search connection. Available Filter names for this operation are:  cross-cluster-search-connection-id destination-domain-info.domain-name destination-domain-info.owner-id destination-domain-info.region source-domain-info.domain-name  . Defaults to None.
        max_results(int, optional): Set this value to limit the number of results returned. If not specified, defaults to 100. Defaults to None.
        next_token(str, optional):  NextToken is sent in case the earlier API call results contain the NextToken. It is used for pagination. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.es.outbound_cross_cluster_search_connection.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.es.outbound_cross_cluster_search_connection.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="es",
        operation="describe_outbound_cross_cluster_search_connections",
        op_kwargs={
            "Filters": filters,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )
